/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* 
 * lt-tag.h
 * Copyright (C) 2011-2012 Akira TAGOH
 * 
 * Authors:
 *   Akira TAGOH  <akira@tagoh.org>
 * 
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#if !defined (__LANGTAG_H__INSIDE) && !defined (__LANGTAG_COMPILATION)
#error "Only <liblangtag/langtag.h> can be included directly."
#endif

#ifndef __LT_TAG_H__
#define __LT_TAG_H__

#include <glib.h>
#include <liblangtag-gobject/lt-lang.gir.h>
#include <liblangtag-gobject/lt-extlang.gir.h>
#include <liblangtag-gobject/lt-script.gir.h>
#include <liblangtag-gobject/lt-region.gir.h>
#include <liblangtag-gobject/lt-extension.gir.h>
#include <liblangtag-gobject/lt-grandfathered.gir.h>

G_BEGIN_DECLS

/**
 * LtTag:
 *
 * All the fields in the <structname>LtTag</structname>
 * structure are private to the #LtTag implementation.
 */
typedef struct _LtTag	LtTag;


LtTag                 *lt_tag_new              (void);
LtTag                 *lt_tag_ref              (LtTag        *tag);
void                      lt_tag_unref            (LtTag        *tag);
gboolean                  lt_tag_parse            (LtTag        *tag,
                                                   const gchar     *tag_string,
                                                   GError         **error);
void                      lt_tag_clear            (LtTag        *tag);
LtTag                 *lt_tag_copy             (const LtTag  *tag);
gboolean                  lt_tag_truncate         (LtTag        *tag,
                                                   GError         **error);
const gchar              *lt_tag_get_string       (LtTag        *tag);
gchar                    *lt_tag_canonicalize     (LtTag        *tag,
                                                   GError         **error);
gchar                    *lt_tag_convert_to_locale(LtTag        *tag,
                                                   GError         **error);
void                      lt_tag_dump             (const LtTag  *tag);
gboolean                  lt_tag_compare          (const LtTag  *v1,
                                                   const LtTag  *v2);
gboolean                  lt_tag_match            (const LtTag  *v1,
                                                   const gchar     *v2,
                                                   GError         **error);
gchar                    *lt_tag_lookup           (const LtTag  *tag,
                                                   const gchar     *pattern,
                                                   GError         **error);
const LtLang          *lt_tag_get_language     (const LtTag  *tag);
const LtExtlang       *lt_tag_get_extlang      (const LtTag  *tag);
const LtScript        *lt_tag_get_script       (const LtTag  *tag);
const LtRegion        *lt_tag_get_region       (const LtTag  *tag);
const GList              *lt_tag_get_variants     (const LtTag  *tag);
const LtExtension     *lt_tag_get_extension    (const LtTag  *tag);
const GString            *lt_tag_get_privateuse   (const LtTag  *tag);
const LtGrandfathered *lt_tag_get_grandfathered(const LtTag  *tag);

G_END_DECLS

#endif /* __LT_TAG_H__ */
